@@ -202,7 +202,7 @@ bool Attica::KdePlatformDependent::askForCredentials(const QUrl& baseUrl, QStrin
 QList<QUrl> KdePlatformDependent::getDefaultProviderFiles() const
 {
     KConfigGroup group(m_config, "General");
-    QStringList pathStrings = group.readPathEntry("providerFiles", QStringList(QStringLiteral("http://download.kde.org/ocs/providers.xml")));
+    QStringList pathStrings = group.readPathEntry("providerFiles", QStringList(QStringLiteral("https://download.kde.org/ocs/providers.xml")));
     QList<QUrl> paths;
     foreach (const QString& pathString, pathStrings) {
         paths.append(QUrl(pathString));
@@ -214,7 +214,7 @@ QList<QUrl> KdePlatformDependent::getDefaultProviderFiles() const
 void KdePlatformDependent::addDefaultProviderFile(const QUrl& url)
 {
     KConfigGroup group(m_config, "General");
-    QStringList pathStrings = group.readPathEntry("providerFiles", QStringList(QStringLiteral("http://download.kde.org/ocs/providers.xml")));
+    QStringList pathStrings = group.readPathEntry("providerFiles", QStringList(QStringLiteral("https://download.kde.org/ocs/providers.xml")));
     QString urlString = url.toString();
     if(!pathStrings.contains(urlString)) {
         pathStrings.append(urlString);
@@ -227,7 +227,7 @@ void KdePlatformDependent::addDefaultProviderFile(const QUrl& url)
 void KdePlatformDependent::removeDefaultProviderFile(const QUrl& url)
 {
     KConfigGroup group(m_config, "General");
-    QStringList pathStrings = group.readPathEntry("providerFiles", QStringList(QStringLiteral("http://download.kde.org/ocs/providers.xml")));
+    QStringList pathStrings = group.readPathEntry("providerFiles", QStringList(QStringLiteral("https://download.kde.org/ocs/providers.xml")));
     pathStrings.removeAll(url.toString());
     group.writeEntry("providerFiles", pathStrings);
 }
